package ehu.student.oo.ui;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics;

/**
 * Un JTablero es un componente grafico que aparece dibujado
 * en una ventana como un tablero, o casillero, con casillas rectangulares.
 * 
 * El tablero tiene un numero dado de filas y columnas
 * Todas las casillas tienen la misma anchura y altura, medidas en "pixel"s.
 */
public class JTableroSimple extends javax.swing.JComponent
{
	private static final long serialVersionUID = 1L;

	/*
	 * Numero de casillas del tablero
	 */
	private int numberOfRows = 12;
	private int numberOfColumns = 15;

	/*
	 * Dimensiones de cada casilla (en pixels)
	 */
	private int cellWidth = 40;
	private int cellHeight = 40;

	/*
	 * Dimensiones del tablero (en pixels)
	 */
	private int anchoTotal = numberOfColumns * cellWidth+1;
	private int altoTotal = numberOfRows * cellHeight+1;

	/*
	 * Colores usados para el dibujo del tablero
	 */
	private Color colorFondo = Color.yellow;
	private Color colorLineas = Color.blue;


	/**
	 * Crea un nuevo tablero con las dimensiones establecidas por defecto.
	 */
	public JTableroSimple()
	{    
		/*
		 * Para establecer las dimensiones de este componente en una ventana
		 * 
		 * Dimension es modificable!!!
		 */
		setPreferredSize(new Dimension(anchoTotal, altoTotal));
		setSize(new Dimension(anchoTotal, altoTotal));
	}

	/**
	 * Dibujar el tablero.
	 * 
	 * @param g el contexto grafico en el cual se pinta.
	 */
	@Override
	public void paint(Graphics g){
		pintarFondo(g);
		pintarLineasVerticales(g);
		pintarLineasHorizontales(g);
	}

	/**
	 * Dibujar el fondo del tablero.
	 * 
	 * @param g el contexto grafico en el cual se pinta.
	 */
	private void pintarFondo(Graphics g){
		g.setColor(colorFondo);
		g.fillRect(0, 0, anchoTotal, altoTotal);    	
	}

	/**
	 * Dibujar las lineas verticales del tablero.
	 * 
	 * @param g el contexto grafico en el cual se pinta.
	 */
	private void pintarLineasVerticales(Graphics g){
		g.setColor(colorLineas);
		for(int i = 0; i <= numberOfColumns; i++){
			int x0 = i*cellWidth;
			int y0 = 0;
			int x1 = x0;
			int y1 = numberOfRows*cellHeight;

			g.drawLine(x0, y0, x1, y1);
		}        
	}

	/**
	 * Dibujar las lineas horizontales del tablero.
	 * 
	 * @param g el contexto grafico en el cual se pinta.
	 */
	private void pintarLineasHorizontales(Graphics g){
		g.setColor(colorLineas);
		for(int i = 0; i <= numberOfRows; i++){
			int x0 = 0;
			int y0 = i*cellHeight;
			int x1 = numberOfColumns*cellWidth;
			int y1 = y0;

			g.drawLine(x0, y0, x1, y1);
		}
	}

	public int getNumberOfRows() {
		return numberOfRows;
	}

	public int getNumberOfColumns() {
		return numberOfColumns;
	}

	public int getCellWidth() {
		return cellWidth;
	}

	public int getCellHeight() {
		return cellHeight;
	}

}