package ehu.student.oo.ui;

import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.IOException;
import java.net.MalformedURLException;
import java.net.URL;

import javax.swing.JButton;
import javax.swing.JEditorPane;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextField;

/**
 * Una ventana con botones, campos de texto, etc.
 * Se visualiza el contenido de la pagina web que indique el usuario.
 */
public class VentanaConComponentes extends JFrame
{
	private static final long serialVersionUID = 1L;

	private static final String HOME_PAGE = 
		"http://www.bolsamadrid.es/esp/mercados/acciones/accind1_1.htm";
		//"http://www.sun.com/";
	
	/* Ancho del campo de texto usado para escribir direcciones web */
	private static final int URL_TEXT_FIELD_COLUMNS = 50;
	
	/* 
	 * Dimensiones de la ventana de texto usada para visualizar la pagina web
	 * elegida por el usuario (en pixels)
	 */
	private static final int EDT_PANE_HEIGHT = 650;
	private static final int EDT_PANE_WIDTH = 850;

	/* 
	 * Ventana de texto usada para visualizar la pagina web
	 * elegida por el usuario.
	 */
	private JEditorPane edtPane = new JEditorPane();

	/*
	 * La ventana de texto se visualiza con barras de scroll.
	 */
	private JScrollPane scrollPane = new JScrollPane(edtPane);

	/*
	 * Botones, etc para que el usuario introduzca
	 * la direccion de la pagina a visualizar.
	 */
	private JLabel urlLabel = new JLabel("URL");
	private JTextField urlTextField = new JTextField(HOME_PAGE);
	private JButton goButton = new JButton("Go");
	private JButton finButton = new JButton("Fin");

	/*
	 * Paneles para colocar componentes
	 */
	private JPanel panelCentro = new JPanel();
	private JPanel panelNorte = new JPanel();    
	private JPanel panelSur = new JPanel();    
	private JPanel panelEste = new JPanel();
	private JPanel panelOeste = new JPanel();

	/**
	 * Construye una nueva VentanaConComponentes.
	 */
	public VentanaConComponentes(){
		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);	
		
		/*
		 * Establecer la anchura (en caracteres)
		 * del campo de texto donde se introduce la direccion
		 * de la pagina web.
		 */
		urlTextField.setColumns(URL_TEXT_FIELD_COLUMNS);

		/*
		 * No se permite modificar el contenido de  la ventana donde
		 * se visualiza la pagina web.
		 */
		edtPane.setEditable(false);
		
		/*
		 * Establecer las dimensiones de la ventana donde
		 * se visualiza la pagina web.
		 */
		edtPane.setSize(EDT_PANE_WIDTH, EDT_PANE_HEIGHT);
		edtPane.setPreferredSize(new Dimension(EDT_PANE_WIDTH, EDT_PANE_HEIGHT));

		/*
		 * Colocar paneles en la ventana
		 */
		add("North", panelNorte);
		add("Center", panelCentro);
		add("South", panelSur);
		add("East", panelEste);
		add("West", panelOeste);

		/*
		 * Colocar componentes en los paneles
		 */
		panelNorte.add(urlLabel);
		panelNorte.add(urlTextField);
		panelNorte.add(goButton);
		panelSur.add(finButton);
		panelCentro.add(scrollPane);

		/*
		 * Para ajustar automaticamente las dimensiones de la ventana
		 * segun el numero y dimensiones de los elementos que contiene
		 */
		pack();

		/*
		 * Acciones asociadas a los botones de Fin y Go
		 */
		finButton.addActionListener(new ActionListener(){

			public void actionPerformed(ActionEvent e) {
				System.exit(0);
			}
		});
		
		goButton.addActionListener(new ActionListener(){

			public void actionPerformed(ActionEvent e) {
				goButtonActionPerformed(e);
			}});
	}


	/**
	 * Visualizar la pagina web elegida por el usuario.
	 * 
	 * Ejecutado cuando el usuario pincha el boton Go.
	 * 
	 * @param e el evento que dispara este metodo.
	 */
	private void goButtonActionPerformed(ActionEvent e) {
		/*
		 * Examinar el texto que ha introducido
		 * el usuario en el campo de texto.
		 */
		String text = urlTextField.getText();
		
		/*
		 * Crear una copia de ese texto sin blancos
		 * al principio ni al final.
		 */
		text = text.trim();
		
		/*
		 * Crear la URL correspondiente a la direccion de la pagina
		 * introducida por el usuario (si es posible)
		 */
		URL url = null;
		try {
			url = new URL(text);
		} catch (MalformedURLException e1) {
			e1.printStackTrace();
		}
		
		if (url != null){
			/*
			 * Direccion introducida por el usuario es valida:
			 * descargar y visualizar el contenido de la pagina web (si es posible) 
			 */
			try {
				edtPane.setPage(url);
			} catch (IOException e1) {
				e1.printStackTrace();
			}
		}
	}

	/*
	 * Puesta en marcha...
	 */
	public static void main(String args[])
	{
		VentanaConComponentes v = new VentanaConComponentes();
		v.setVisible(true);
	}
}