package ehu.student.oo.ui;

import javax.swing.JFrame;

/**
 * Una ventana con un tablero dibujado en el centro.
 * 
 * Se dibuja una figura desplazandose a traves del tablero.
 * La figura va cambiando a medida que se desplaza
 * de una posicion a otra.
 */
public class VentanaConTablero extends JFrame
{
	private static final long serialVersionUID = 1L;

	private JTablero tablero = new JTablero();


	/**
	 * Construye una nueva ventana
	 */
	public VentanaConTablero(){
		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);

		add("Center", tablero);

		/*
		 * Para ajustar automaticamente las dimensiones de la ventana
		 * segun el numero y dimensiones de los elementos que contiene
		 */
		pack();
	}

	/**
	 * Dibujar una figura desplazandose a traves del tablero.
	 * 
	 * La figura va cambiando a medida que se desplaza el puntero
	 * de una posicion a otra.
	 * Su posicion se cambia a intervalos de 100 milisegundos.
	 */
	public void test()
	{
		/*
		 * Coordenadas donde se situa la figura
		 */
		int x = 0;
		int y = 0;
		
		/*
		 * Codigo numerico correspondiente al estilo de dibujo del cursor
		 * del tablero.
		 */
		int estilo = JTablero.CURSOR_STYLE_CIRCLE;
		while (true){
			tablero.setCursorStyle(estilo);
			tablero.setCursorAt(x, y);
			
			/*
			 * Esperar 100 milisegundos antes de seguir
			 */
			try {
				Thread.sleep(100);
			} catch (InterruptedException e) {
				e.printStackTrace();
			}
			
			/*
			 * Calcular coordenadas de la siguiente posicion del cursor
			 */
			x = x + 1;
			y = y + 1;
			if (x == tablero.getWidth()){
				x = 0;
			}
			if (y == tablero.getHeight()){
				y = 0;
			}
			
			
			/*
			 * Calcular nuevo codigo de estilo de dibujo del cursor
			 * del tablero
			 */
			if (estilo == JTablero.CURSOR_STYLE_CIRCLE){
				estilo = JTablero.CURSOR_STYLE_IMG;
			} else if (estilo == JTablero.CURSOR_STYLE_IMG){
				estilo = JTablero.CURSOR_STYLE_STRING;
			} else if (estilo == JTablero.CURSOR_STYLE_STRING){
				estilo = JTablero.CURSOR_STYLE_CIRCLE;
			}
		}
	}


	/*
	 * Puesta en marcha...
	 */
	public static void main(String args[])
	{
		VentanaConTablero v = new VentanaConTablero();
		v.setVisible(true);
		v.test();
	}
}